
# Autodistill autodistill-efficientnet

![Autodistill banner](https://raw.githubusercontent.com/autodistill/autodistill/main/docs/assets/banner.png)

The autodistill-efficientnet package integrates with the [Autodistill ecosystem](https://autodistill.com), a framework for distilling large models into smaller, edge-ready models.

If you are interested in implementing the autodistill-efficientnet package for use with Autodistill, leave an issue on the main [Autodistill GitHub repository](https://github.com/autodistill/autodistill) to discuss getting started.
    